@@ -2,7 +2,7 @@
 # Run this to generate all the initial makefiles, etc.
 #
 # Copyright (C) 2010 - 2011, Robert Ancell <robert.ancell@canonical.com>
-# Copyright (C) 2017 - 2018, Sean Davis <smd.seandavis@gmail.com>
+# Copyright (C) 2017 - 2020, Sean Davis <sean@bluesabre.org>
 #
 # This program is free software: you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -10,6 +10,17 @@
 # version. See http://www.gnu.org/copyleft/gpl.html the full text of the
 # license.
 #
+
+(type xdt-csource) >/dev/null 2>&1 || {
+  cat >&2 <<EOF
+autogen.sh: You don't seem to have the Xfce development tools installed on
+            your system, which are required to build this software.
+            Please install the xfce4-dev-tools package first, it is available
+            from your distribution or https://www.xfce.org/.
+EOF
+  exit 1
+}
+
 test -n "$srcdir" || srcdir=$(dirname "$0")
 test -n "$srcdir" || srcdir=.
 
