@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014 - 2018, Sean Davis <smd.seandavis@gmail.com>
+ * Copyright (C) 2014 - 2020, Sean Davis <sean@bluesabre.org>
  * Copyright (C) 2014, Andrew P. <pan.pav.7c5@gmail.com>
  * Copyright (C) 2015, Robert Ancell <robert.ancell@canonical.com>
  * Copyright (C) 2015, Simon Steinbeiß <ochosi@shimmerproject.org>
@@ -342,7 +342,7 @@ greeter_background_class_init(GreeterBackgroundClass* klass)
 static void
 greeter_background_init(GreeterBackground* self)
 {
-    GreeterBackgroundPrivate* priv = G_TYPE_INSTANCE_GET_PRIVATE(self, GREETER_BACKGROUND_TYPE, GreeterBackgroundPrivate);
+    GreeterBackgroundPrivate* priv = greeter_background_get_instance_private (self);
     self->priv = priv;
 
     priv->screen = NULL;
